
%define daemon_group apache
%define daemon_user monitor

%define database_group postgres
%define database_user postgres

%define logger_user op5lsu

Name:       op5-logger
Version:    %{op5version}
Release:    %{op5release}%{?dist}
License:    op5 Software License
Vendor:     op5 AB
Url:        https://www.itrsgroup.com
BuildRoot:  %{_tmppath}/%name-%version
Summary:    The op5 Logger extension
Group:      Applications/Internet
BuildArch:  i386 x86_64
Prefix:     /opt/logger
Source0:    %name-%version.tar.gz

# obsolete old logserver packages, they have now been merged into this
# op5-logger package

Conflicts: op5-logserver-connector-fs

Provides: op5-logserver-auth = %version
Provides: op5-logserver-reports = %version
Provides: op5-logserver = %version
Provides: op5-logserver-gui = %version
Provides: op5-logserver-release = %version
Provides: op5-logserver-rotate = %version
Provides: op5-logserver-migrate2to3 = %version
Provides: op5-postgresql-config = %version
Provides: op5-logger-backup = %version
Provides: op5-syslog-ng = %version
Provides: logfilter = %version
Provides: monitor-passive-logs = 3.2.5

Obsoletes: op5-logserver-auth < %version
Obsoletes: op5-logserver-reports < %version
Obsoletes: op5-logserver < %version
Obsoletes: op5-logserver-gui < %version
Obsoletes: op5-logserver-release < %version
Obsoletes: op5-logserver-rotate < %version
Obsoletes: op5-logserver-migrate2to3 < %version
Obsoletes: op5-postgresql-config < %version
Obsoletes: op5-logger-backup < %version
Obsoletes: op5-syslog-ng < %version
Obsoletes: logfilter < %version
Obsoletes: monitor-passive-logs < 3.2.5

# ninja module requirements
Requires: op5-monitor-user
Requires: monitor-ninja
Requires: monitor-nacoma
Requires: php-pgsql

# logfilter requirements
Requires: libicu > 4.2

# logger db requirements
Requires: postgresql-server >= 8.4.0
Requires: postgresql >= 8.4.0
Requires: python-psycopg2
Requires: python-argparse
Requires: bzip2
Requires: op5-logserver-db

# syslog requirement
Requires: rsyslog
Requires: rsyslog-pgsql

# ninja module requirements
BuildRequires: monitor-ninja-devel
BuildRequires: op5-monitor-user

# logfilter requirements
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: check-devel
BuildRequires: valgrind
BuildRequires: pkgconfig
BuildRequires: libicu-devel > 4.2

%description
Introduces the op5 Monitor Logger extension, providing syslog functionality and
graphical user interface for searching through logs

%package -n op5-logserver-db
Summary: Meta-package to prevent uninstallation of postgres
Version: %{op5version}
Group: op5/logger

%description -n op5-logserver-db
Meta-package to prevent uninstallation of postgres

%package test
Summary: Test requirements for Logger
Group: op5/logger
Requires: gcc
Requires: op5backup
Requires: chromedriver
Requires: php-phpunit-PHPUnit
Requires: python-nose
Requires: ruby
Requires: ruby-devel
Requires: op5int_webtest

%description test
Test requirements

%prep
%setup -q

%build
php build.php
echo %{version} > .version_number
autoreconf -i

%configure
make

%install
rm --recursive --force %buildroot

# install ninja module
mkdir --parents --mode 755 %buildroot/opt/monitor/op5/ninja/modules
cp --recursive logger %buildroot/opt/monitor/op5/ninja/modules/logger
# owned by test
cp --recursive testdeps %buildroot/opt/monitor/op5/ninja/modules/testdeps

# install logfilter
%make_install

# install logger db
mkdir --parents %{buildroot}%prefix
touch %buildroot%prefix/logserver-db-metapackage

cp *.sh %{buildroot}%prefix
cp --recursive configs %{buildroot}%prefix/configs
cp --recursive sql %{buildroot}%prefix/sql
cp --recursive upgrade %{buildroot}%prefix/upgrade

# install logger backup
mkdir --parents %buildroot%{_sysconfdir}/op5-backup/modules/external
cp ./scripts/op5-logger-backup.sh %buildroot%{_sysconfdir}/op5-backup/modules/external/op5-logger

# install syslog service
mkdir --parents %{buildroot}%{_var}/log/op5/logger
mkdir --parents %{buildroot}/opt/logger/scripts
mkdir --parents %{buildroot}%{_sysconfdir}/cron.d
cp ./scripts/*.py %{buildroot}/opt/logger/scripts/
cp ./configs/op5-logger-logrotate.cron %{buildroot}%{_sysconfdir}/cron.d/op5-logger-logrotate

mkdir --parents %{buildroot}%{_sysconfdir}/rsyslog.d/
cp ./configs/op5-rsyslog.conf %{buildroot}%{_sysconfdir}/rsyslog.d/
cp ./configs/op5-rsyslog-file.conf %{buildroot}%{_sysconfdir}/rsyslog.d/
cp ./configs/op5-rsyslog-pgsql.conf %{buildroot}%{_sysconfdir}/rsyslog.d/

%check
make check

%files test
%attr(755,%daemon_user,%daemon_group) /opt/monitor/op5/ninja/modules/testdeps

%files -n op5-logserver-db
%prefix/logserver-db-metapackage

%files
%defattr(-,root,root,755)
%prefix
%prefix/scripts/*
%{_sysconfdir}/cron.d/op5-logger-logrotate
%{_bindir}/logfilter
%dir %{_var}/log/op5/logger
%{_sysconfdir}/op5-backup/modules/external/op5-logger*
%attr(755,%daemon_user,%daemon_group) /opt/monitor/op5/ninja/modules/logger
%exclude %prefix/sql/README
%exclude /opt/monitor/op5/ninja/modules/testdeps

%{_sysconfdir}/rsyslog.d/op5-rsyslog.conf
%{_sysconfdir}/rsyslog.d/op5-rsyslog-file.conf
%{_sysconfdir}/rsyslog.d/op5-rsyslog-pgsql.conf

%clean
rm -rf %buildroot

%post
# ninja module
existing=$(mysql -sN -uroot merlin -e 'select count(1) from scheduled_report_types where identifier = "logger"')
if [ "$existing" -eq "0" ]; then
        mysql -uroot merlin -e "INSERT INTO scheduled_report_types (name, identifier) VALUES ('Logger archive reports', 'logger')";
fi

getent passwd %logger_user > /dev/null
if [ $? -eq 2 ]; then  # user doesn't exist in passwd database
    useradd --create-home %logger_user
fi

# logger db
if [ "$1" -eq 1 ]
then

    if [ ! -f "%{_sharedstatedir}/pgsql/data/PG_VERSION" ]; then
        postgresql-setup initdb
    fi

    install --backup --preserve-timestamps --mode 600 --group %database_group --owner %database_user %prefix/configs/.i18n %{_sharedstatedir}/pgsql/.i18n
    install --backup --preserve-timestamps --mode 600 --group %database_group --owner %database_user %prefix/configs/pg_hba.conf %{_sharedstatedir}/pgsql/data/pg_hba.conf

    systemctl restart postgresql.service
    sleep 1 # bad idea, but whatever floats this bloat

    echo -n "Creating op5-logger database : "
    if [ ! $(su -l postgres -c "psql -U postgres -l -t | cut -d '|' -f 1 | grep %logger_user") ]; then
        su -l %database_user -c "PGOPTIONS='--client-min-messages=warning' psql --quiet --no-psqlrc --set=ON_ERROR_ROLLBACK --set=ON_ERROR_STOP=1 -U %database_user -d %database_user -f %prefix/sql/create_database.sql"
        su -l %logger_user -c "PGOPTIONS='--client-min-messages=warning' psql --quiet --no-psqlrc --set=ON_ERROR_ROLLBACK --set=ON_ERROR_STOP=1 -U %logger_user -d %logger_user -f %prefix/sql/create_functions.sql"
        su -l %logger_user -c "PGOPTIONS='--client-min-messages=warning' psql --quiet --no-psqlrc --set=ON_ERROR_ROLLBACK --set=ON_ERROR_STOP=1 -U %logger_user -d %logger_user -f %prefix/sql/create_tables.sql"
    else
        echo "Database for op5-logger already exists"
    fi

    systemctl enable postgresql.service --now

    echo -n "Upgrading op5-logger database : "
    %prefix/upgrade.sh | tee "%prefix/db.update.log" 2>&1 && echo "[  OK  ]" || echo "[FAILED]"

else
    # Update
    install --backup --preserve-timestamps --mode 600 --group %database_group --owner %database_user %prefix/configs/.i18n %{_sharedstatedir}/pgsql/.i18n
    install --backup --preserve-timestamps --mode 600 --group %database_group --owner %database_user %prefix/configs/pg_hba.conf %{_sharedstatedir}/pgsql/data/pg_hba.conf

    systemctl restart postgresql.service
    sleep 1 # bad idea, but whatever floats this bloat

    echo -n "Upgrading op5-logger database : "
    %prefix/upgrade.sh | tee "%prefix/db.update.log" 2>&1 && echo "[  OK  ]" || echo "[FAILED]"

    systemctl restart postgresql.service
    sleep 1 # bad idea, but whatever floats this bloat

fi

systemctl restart rsyslog.service

%preun

# Cleanup on uninstallation
if [ $1 -eq 0 ]; then
    systemctl stop rsyslog.service

    if su -l %database_user -c "psql -U %database_user -l -t | cut -d '|' -f 1 | grep -q %logger_user"; then
        echo "Destroying op5-logger database : %logger_user"
        su -l %database_user -c "PGOPTIONS='--client-min-messages=warning' psql --quiet --no-psqlrc --set=ON_ERROR_ROLLBACK --set=ON_ERROR_STOP=1 -U %database_user -d %database_user -f %prefix/sql/destroy_database.sql"
    fi

    systemctl start rsyslog.service

    userdel -r %logger_user
    systemctl disable postgresql.service --now
fi

%posttrans
# this is run after all other transactions, which means we
# *always* start the service even if it gets stopped by
# the "postun" scriptlet of an earlier package
systemctl enable postgresql.service || :
systemctl start postgresql || :

%changelog
* Tue Jun  1 2021 Aksel Sjögren <asjogren@itrsgroup.com>
- Remove EL6 support.
* Mon Jan 27 2020 Aksel Sjögren <asjogren@itrsgroup.com>
- Don't run cleanup script on upgrades.
- Fix removal of database on cleanup.

* Fri Nov 3 2017 Tobias Sjöndin <tobias.sjondin@op5.com>
- Fixed configuration for rsyslog on EL7
